@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2013 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: scriptLibInfo.php 6110 2013-06-13 21:41:24Z fishbone $
+ * @version    SVN: $Id$
  * @link       http://www.magic3.org
  */
 class ScriptLibInfo
@@ -70,6 +70,7 @@ class ScriptLibInfo
 	const LIB_JQUERY_CLOUDCAROUSEL	= 'jquery.cloudcarousel';
 //	const LIB_JQUERY_JQEASYPANEL	= 'jquery.jqeasypanel';
 	const LIB_JQUERY_SCROLLTO		= 'jquery.scrollto';
+	const LIB_JQUERY_FULLCALENDAR	= 'jquery.fullcalendar';
 	
 	// CodeMirror
 	const LIB_CODEMIRROR_JAVASCRIPT	= 'codemirror.javascript';		// CodeMirror Javascript
@@ -91,6 +92,7 @@ class ScriptLibInfo
 	const JQUERY_CLOUDCAROUSEL_VER	= '1.0.5';
 //	const JQUERY_JQEASYPANEL_VER	= '1.0';
 	const JQUERY_SCROLLTO_VER		= '1.4.3.1';
+	const JQUERY_FULLCALENDAR_VER	= '1.6.2';
 	// その他ライブラリバージョン
 	const CODEMIRROR_VER			= '3.1';
 	
@@ -159,6 +161,9 @@ const JQUERY_JQPLOT_CSS				= 'jquery/jqplot1.0.7/jquery.jqplot.min.css';
 //	const JQUERY_JQEASYPANEL_FILENAME	= 'jquery/jquery.jqEasyPanel.js';
 //	const JQUERY_JQEASYPANEL_CSS		= 'jquery/jqeasypanel.css';
 	const JQUERY_SCROLLTO_FILENAME		= 'jquery/jquery.scrollTo-1.4.3.1-min.js';
+//	const JQUERY_FULLCALENDAR_FILENAME	= 'jquery/fullcalendar-1.6.2/fullcalendar.min.js';
+	const JQUERY_FULLCALENDAR_FILENAME	= 'jquery/fullcalendar-1.6.3/fullcalendar.js';
+	const JQUERY_FULLCALENDAR_CSS		= 'jquery/fullcalendar-1.6.3/fullcalendar.css';
 	
 	// ライブラリの公式サイトのURL
 	const JQUERY_JCAROUSEL_URL			= 'http://sorgalla.com/projects/jcarousel/';
@@ -177,6 +182,7 @@ const JQUERY_JQPLOT_CSS				= 'jquery/jqplot1.0.7/jquery.jqplot.min.css';
 	const JQUERY_CLOUDCAROUSEL_URL		= 'http://www.professorcloud.com/mainsite/carousel.htm';
 //	const JQUERY_JQEASYPANEL_URL		= 'http://www.jqeasy.com/';
 	const JQUERY_SCROLLTO_URL			= 'http://flesler.blogspot.jp/2007/10/jqueryscrollto.html';
+	const JQUERY_FULLCALENDAR_URL		= 'http://arshaw.com/fullcalendar/';
 	const CODEMIRROR_URL				= 'http://codemirror.net/';		// CodeMirror
 	
 	// ディレクトリ名
@@ -189,12 +195,13 @@ const JQUERY_JQPLOT_CSS				= 'jquery/jqplot1.0.7/jquery.jqplot.min.css';
 //	const JQUERY_UI_CORE_FILENAME	= 'jquery-ui-core-1.10.1.min.js';			// JQuery UI Core (Core,Interactions)
 	const JQUERY_UI_CORE_FILENAME	= 'jquery-ui-core-1.9.2.min.js';			// JQuery UI Core (Core,Interactions)
 	const FCKEDITOR_FILENAME		= 'fckeditor2.6.6/fckeditor.js';			// FCKEditor
-//	const CKEDITOR_FILENAME			= 'ckeditor4.0.1/ckeditor.js';				// CKEditor
-	const CKEDITOR_FILENAME			= 'ckeditor4.1.0/ckeditor.js';				// CKEditor
+	const CKEDITOR_FILENAME			= 'ckeditor4.2.0/ckeditor.js';				// CKEditor
 	const MD5_FILENAME				= 'md5.js';									// MD5
 	const SWFOBJECT_FILENAME		= 'swfobject/swfobject.js';					// swfobject
-	const BOOTSTRAP_FILENAME		= 'bootstrap/bootstrap2.3.min.js';			// bootstrap
-	const BOOTSTRAP_CSS				= 'bootstrap/bootstrap2.3.css';
+//	const BOOTSTRAP_FILENAME		= 'bootstrap/bootstrap2.3.min.js';			// bootstrap
+	const BOOTSTRAP_FILENAME		= 'bootstrap/bootstrap3.0rc2.js';			// bootstrap
+//	const BOOTSTRAP_CSS				= 'bootstrap/bootstrap2.3.css';
+	const BOOTSTRAP_CSS				= 'bootstrap/bootstrap3.0rc2.css';
 	const BOOTSTRAP_OPTION_CSS		= 'bootstrap/bootstrap-box2.3.css';
 	
 	const CODEMIRROR_FILENAME				= 'codemirror-3.1/lib/codemirror.js';				// CodeMirror
@@ -363,6 +370,11 @@ const JQUERY_JQPLOT_CSS				= 'jquery/jqplot1.0.7/jquery.jqplot.min.css';
 					self::LIB_JQUERY_SCROLLTO		=>	array(	'script' 	=> array(self::JQUERY_SCROLLTO_FILENAME),	// jquery.scrollto用のファイル
 																'url'		=> self::JQUERY_SCROLLTO_URL,
 																'version'	=> self::JQUERY_SCROLLTO_VER),
+					self::LIB_JQUERY_FULLCALENDAR	=>	array(	'script' 	=> array(self::JQUERY_FULLCALENDAR_FILENAME),	// jquery.FullCalendar用のファイル
+																'css'		=> array(self::JQUERY_FULLCALENDAR_CSS),
+																'url'		=> self::JQUERY_FULLCALENDAR_URL,
+																'version'	=> self::JQUERY_FULLCALENDAR_VER),
+																
 /*					self::LIB_JQUERY_JQEASYPANEL	=>	array(	'script' 	=> array(self::JQUERY_JQEASYPANEL_FILENAME),	// jquery.jqEasyPanel用のファイル
 																'css'		=> array(self::JQUERY_JQEASYPANEL_CSS),
 																'url'		=> self::JQUERY_JQEASYPANEL_URL,
