@@ -1,6 +1,6 @@
 <?php
 /**
- * コンテナクラス
+ * index.php用コンテナクラス
  *
  * PHP versions 5
  *
@@ -8,24 +8,23 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2009 Magic3 Project.
+ * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_ec_mainDelivmethodWidgetContainer.php 2623 2009-12-05 12:40:38Z fishbone $
+ * @version    SVN: $Id: admin_ec_mainDelivmethodWidgetContainer.php 5440 2012-12-08 09:37:39Z fishbone $
  * @link       http://www.magic3.org
  */
+//require_once($gEnvManager->getCurrentWidgetContainerPath() . '/admin_ec_mainBaseWidgetContainer.php');
 require_once($gEnvManager->getCurrentWidgetContainerPath() . '/admin_ec_mainBaseWidgetContainer.php');
 require_once($gEnvManager->getCurrentWidgetDbPath() .	'/ec_mainDelivMethodDb.php');
 
 class admin_ec_mainDelivmethodWidgetContainer extends admin_ec_mainBaseWidgetContainer
 {
 	private $db;	// DB接続オブジェクト
-	private $sysDb;		// システムDBオブジェクト
 	private $langId;		// 表示言語
 	private $iWidgetId;	// インナーウィジェットID
 	private $serialNo;		// 選択中の項目のシリアル番号
 	private $serialArray = array();		// 表示されている項目シリアル番号
 	const IWIDGET_TYPE = 'DELIVERY';		// 配送方法用インナーウィジェット
-	const TARGET_WIDGET = 'ec_main';		// プレビュー画面表示用
 	const DELIV_TASK = 'delivmethod';		// 配送方法選択画面表示用
 	
 	/**
@@ -38,7 +37,6 @@ class admin_ec_mainDelivmethodWidgetContainer extends admin_ec_mainBaseWidgetCon
 		
 		// DBオブジェクト作成
 		$this->db = new ec_mainDelivMethodDb();
-		$this->sysDb = $this->gInstance->getSytemDbObject();
 	}
 	/**
 	 * テンプレートファイルを設定
@@ -115,8 +113,8 @@ class admin_ec_mainDelivmethodWidgetContainer extends admin_ec_mainBaseWidgetCon
 		$this->tmpl->addVar("_widget", "serial_list", implode($this->serialArray, ','));// 表示項目のシリアル番号を設定
 		
 		// プレビュー表示ボタンのリンクを作成
-		//$url = $this->gPage->createWidgetCmdUrl($this->gEnv->getDefaultPageId(), self::TARGET_WIDGET, ''/*送信元ウィジェット指定なし*/, 'task=' . self::DELIV_TASK);
-		$url = $this->gPage->createWidgetCmdUrl(self::TARGET_WIDGET, ''/*送信元ウィジェット指定なし*/, 'task=' . self::DELIV_TASK, $this->gEnv->getDefaultPageId());
+		$url = $this->gPage->createWidgetCmdUrl($this->gEnv->getCurrentWidgetId(), ''/*送信元ウィジェット指定なし*/,
+									'task=' . self::DELIV_TASK . '&' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_PREVIEW, $this->gEnv->getDefaultPageId());
 		$this->tmpl->addVar("_widget", "url", $this->getUrl($url, true));
 	}
 	/**
@@ -210,6 +208,7 @@ class admin_ec_mainDelivmethodWidgetContainer extends admin_ec_mainBaseWidgetCon
 		} else if ($act == 'selectcalc'){		// 計算方法選択のとき
 			if (!empty($this->iWidgetId)){
 				// パラメータをインナーウィジェットに設定
+				$optionParam = new stdClass;
 				$optionParam->init = true;		// 初期データ取得
 				$this->setIWidgetParam($this->iWidgetId, $this->id, $row['do_param'], $optionParam, true);
 			}
@@ -233,6 +232,7 @@ class admin_ec_mainDelivmethodWidgetContainer extends admin_ec_mainBaseWidgetCon
 		if ($replaceNew){
 			$ret = $this->db->getDelivMethodDef($this->id, $this->langId, 0/*デフォルトのセットID*/, $row);
 			if ($ret){
+				$this->serialNo = $row['do_serial'];	// シリアル番号
 				$addid		= $row['do_id'];	// ID
 				$name		= $row['do_name'];	// 名前
 				$desc		= $row['do_description'];	// 説明
@@ -241,6 +241,7 @@ class admin_ec_mainDelivmethodWidgetContainer extends admin_ec_mainBaseWidgetCon
 				$this->iWidgetId	= $row['do_iwidget_id'];	// インナーウィジェットID
 				if (!empty($this->iWidgetId)){
 					// パラメータをインナーウィジェットに設定
+					$optionParam = new stdClass;
 					$optionParam->init = true;		// 初期データ取得
 					$this->setIWidgetParam($this->iWidgetId, $this->id, $row['do_param'], $optionParam, true);
 				}
@@ -270,7 +271,7 @@ class admin_ec_mainDelivmethodWidgetContainer extends admin_ec_mainBaseWidgetCon
 		$this->tmpl->addVar("_widget", "visible", $visibleStr);		// 表示状態
 		
 		// インナーウィジェット選択メニューを作成
-		$this->sysDb->getAllIWidgetListByType($this->gEnv->getCurrentWidgetId(), self::IWIDGET_TYPE, array($this, 'iWidgetLoop'));
+		$this->_db->getAllIWidgetListByType($this->gEnv->getCurrentWidgetId(), self::IWIDGET_TYPE, array($this, 'iWidgetLoop'));
 		
 		// 選択中のインナーウィジェットの管理画面を取得
 		if (!empty($this->iWidgetId)){
