@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2012 Magic3 Project.
+ * @copyright  Copyright 2006-2013 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_event_mainEntryWidgetContainer.php 5230 2012-09-20 00:50:16Z fishbone $
+ * @version    SVN: $Id$
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_event_mainBaseWidgetContainer.php');
@@ -19,13 +19,13 @@ require_once($gEnvManager->getCurrentWidgetDbPath() .	'/event_mainDb.php');
 class admin_event_mainEntryWidgetContainer extends admin_event_mainBaseWidgetContainer
 {
 //	private $db;	// DB接続オブジェクト
-	private $sysDb;		// システムDBオブジェクト
 	private $serialNo;		// 選択中の項目のシリアル番号
 	private $entryId;
 	private $lang;		// 現在の選択言語
 	private $serialArray = array();		// 表示されている項目シリアル番号
 	private $categoryListData;		// 全記事カテゴリー
 	private $categoryArray;			// 選択中の記事カテゴリー
+	private $categoryCount;			// カテゴリ数
 	const ICON_SIZE = 16;		// アイコンのサイズ
 	const CONTENT_TYPE = 'bg';		// 記事参照数取得用
 	const DEFAULT_LIST_COUNT = 20;			// 最大リスト表示数
@@ -34,6 +34,7 @@ class admin_event_mainEntryWidgetContainer extends admin_event_mainBaseWidgetCon
 	const CALENDAR_ICON_FILE = '/images/system/calendar.png';		// カレンダーアイコン
 	const ACTIVE_ICON_FILE = '/images/system/active.png';			// 公開中アイコン
 	const INACTIVE_ICON_FILE = '/images/system/inactive.png';		// 非公開アイコン
+	const SEARCH_ICON_FILE = '/images/system/search16.png';		// 検索用アイコン
 	
 	/**
 	 * コンストラクタ
@@ -44,8 +45,7 @@ class admin_event_mainEntryWidgetContainer extends admin_event_mainBaseWidgetCon
 		parent::__construct();
 		
 		// DBオブジェクト作成
-		//$this->_db = new event_mainDb();
-		$this->sysDb = $this->gInstance->getSytemDbObject();
+		//self::$_mainDb = new event_mainDb();
 	}
 	/**
 	 * テンプレートファイルを設定
@@ -139,7 +139,7 @@ class admin_event_mainEntryWidgetContainer extends admin_event_mainBaseWidgetCon
 		
 		// DBの保存設定値を取得
 		$maxListCount = self::DEFAULT_LIST_COUNT;
-		$serializedParam = $this->sysDb->getWidgetParam($this->gEnv->getCurrentWidgetId());
+		$serializedParam = $this->_db->getWidgetParam($this->gEnv->getCurrentWidgetId());
 		if (!empty($serializedParam)){
 			$dispInfo = unserialize($serializedParam);
 			$maxListCount = $dispInfo->maxMemberListCountByAdmin;		// 会員リスト最大表示数
@@ -171,7 +171,7 @@ class admin_event_mainEntryWidgetContainer extends admin_event_mainBaseWidgetCon
 				}
 			}
 			if (count($delItems) > 0){
-				$ret = $this->_db->delEntryItem($delItems);
+				$ret = self::$_mainDb->delEntryItem($delItems);
 				if ($ret){		// データ削除成功のとき
 					$this->setGuidanceMsg('データを削除しました');
 					
@@ -197,7 +197,7 @@ class admin_event_mainEntryWidgetContainer extends admin_event_mainBaseWidgetCon
 		if (!empty($search_endDt)) $endDt = $this->getNextDay($search_endDt);
 		
 		// 総数を取得
-		$totalCount = $this->_db->getEntryItemCount($search_startDt, $endDt, $this->categoryArray, $search_keyword, $this->langId);
+		$totalCount = self::$_mainDb->getEntryItemCount($search_startDt, $endDt, $this->categoryArray, $search_keyword, $this->langId);
 
 		// 表示するページ番号の修正
 		$pageCount = (int)(($totalCount -1) / $maxListCount) + 1;		// 総ページ数
@@ -219,12 +219,18 @@ class admin_event_mainEntryWidgetContainer extends admin_event_mainBaseWidgetCon
 		}
 		
 		// 記事項目リストを取得
-		$this->_db->searchEntryItems($maxListCount, $pageNo, $search_startDt, $endDt, $this->categoryArray, $search_keyword, $this->langId, array($this, 'itemListLoop'));
+		self::$_mainDb->searchEntryItems($maxListCount, $pageNo, $search_startDt, $endDt, $this->categoryArray, $search_keyword, $this->langId, array($this, 'itemListLoop'));
 		if (count($this->serialArray) <= 0) $this->tmpl->setAttribute('itemlist', 'visibility', 'hidden');// 投稿記事がないときは、一覧を表示しない
 		
 		// カテゴリーメニューを作成
-		//$this->_db->getAllCategory($this->langId, $this->categoryListData);
-		//$this->createCategoryMenu(1);		// メニューは１つだけ表示
+		self::$_mainDb->getAllCategory($this->langId, $this->categoryListData);
+		$this->createCategoryMenu(1);		// メニューは１つだけ表示
+		
+		// ボタン作成
+		$searchImg = $this->getUrl($this->gEnv->getRootUrl() . self::SEARCH_ICON_FILE);
+		$searchStr = '検索';
+		$this->tmpl->addVar("_widget", "search_img", $searchImg);
+		$this->tmpl->addVar("_widget", "search_str", $searchStr);
 		
 		// 検索結果
 		$this->tmpl->addVar("_widget", "page_link", $pageLink);
@@ -251,6 +257,11 @@ class admin_event_mainEntryWidgetContainer extends admin_event_mainBaseWidgetCon
 		// デフォルト値
 		$defaultLangId	= $this->gEnv->getDefaultLanguage();
 		
+		// DB定義値取得
+		$this->categoryCount = self::$_configArray[event_mainCommonDef::CF_CATEGORY_COUNT];			// カテゴリ数
+		if (empty($this->categoryCount)) $this->categoryCount = event_mainCommonDef::DEFAULT_CATEGORY_COUNT;
+		
+		// 入力値取得
 		$openBy = $request->trimValueOf(M3_REQUEST_PARAM_OPEN_BY);		// ウィンドウオープンタイプ
 		$act = $request->trimValueOf('act');
 		$this->langId = $request->trimValueOf('item_lang');				// 現在メニューで選択中の言語
@@ -274,6 +285,16 @@ class admin_event_mainEntryWidgetContainer extends admin_event_mainBaseWidgetCon
 		$showComment = ($request->trimValueOf('show_comment') == 'on') ? 1 : 0;				// コメントを表示するかどうか
 		$receiveComment = ($request->trimValueOf('receive_comment') == 'on') ? 1 : 0;		// コメントを受け付けるかどうか
 
+		// カテゴリーを取得
+		$this->categoryArray = array();
+		for ($i = 0; $i < $this->categoryCount; $i++){
+			$itemName = 'item_category' . $i;
+			$itemValue = $request->trimValueOf($itemName);
+			if (!empty($itemValue)){		// 0以外の値を取得
+				$this->categoryArray[] = $itemValue;
+			}
+		}
+
 		// 公開期間を取得
 		$start_date = $request->trimValueOf('item_start_date');		// 公開期間開始日付
 		if (!empty($start_date)) $start_date = $this->convertToProperDate($start_date);
@@ -300,7 +321,7 @@ class admin_event_mainEntryWidgetContainer extends admin_event_mainBaseWidgetCon
 			//if ($act == 'select') $this->langId = $defaultLangId;		// 言語は一旦リセット
 			
 			// 登録済みのブログ記事を取得
-			//$this->serialNo = $this->_db->getEntrySerialNoByContentId($this->entryId, $this->langId);
+			//$this->serialNo = self::$_mainDb->getEntrySerialNoByContentId($this->entryId, $this->langId);
 			//if (empty($this->serialNo)){
 			//	// 取得できないときは初期化
 			//	$dataInit = true;		// データ初期化
@@ -309,7 +330,7 @@ class admin_event_mainEntryWidgetContainer extends admin_event_mainBaseWidgetCon
 			//}
 		} else if ($act == 'selectlang'){		// 項目選択の場合
 			// 登録済みのコンテンツデータを取得
-			$this->serialNo = $this->_db->getEntrySerialNoByContentId($this->entryId, $this->langId);
+			$this->serialNo = self::$_mainDb->getEntrySerialNoByContentId($this->entryId, $this->langId);
 			if (empty($this->serialNo)){
 				// 取得できないときは一部初期化
 				//$name = '';				// タイトル
@@ -346,10 +367,10 @@ class admin_event_mainEntryWidgetContainer extends admin_event_mainBaseWidgetCon
 				}
 				
 				if ($act == 'add'){
-					$ret = $this->_db->addEntryItem(0, $this->langId, $name, $html, $html2, $summary, $place, $contact, $url, $note, $status, $this->categoryArray, 
+					$ret = self::$_mainDb->addEntryItem(0, $this->langId, $name, $html, $html2, $summary, $place, $contact, $url, $note, $status, $this->categoryArray, 
 													$startDt, $endDt, $showComment, $receiveComment, false/*参照ユーザ制限なし*/, $newSerial);
 				} else {
-					$ret = $this->_db->addEntryItem($this->entryId, $this->langId, $name, $html, $html2, $summary, $place, $contact, $url, $note, $status, $this->categoryArray, 
+					$ret = self::$_mainDb->addEntryItem($this->entryId, $this->langId, $name, $html, $html2, $summary, $place, $contact, $url, $note, $status, $this->categoryArray, 
 													$startDt, $endDt, $showComment, $receiveComment, false/*参照ユーザ制限なし*/, $newSerial);
 				}
 				if ($ret){
@@ -392,7 +413,7 @@ class admin_event_mainEntryWidgetContainer extends admin_event_mainBaseWidgetCon
 					$endDt = $end_date . ' ' . $end_time;
 				}
 				
-				$ret = $this->_db->updateEntryItem($this->serialNo, $name, $html, $html2, $summary, $place, $contact, $url, $note, $status, $this->categoryArray, 
+				$ret = self::$_mainDb->updateEntryItem($this->serialNo, $name, $html, $html2, $summary, $place, $contact, $url, $note, $status, $this->categoryArray, 
 														$startDt, $endDt, $showComment, $receiveComment, false/*参照ユーザ制限なし*/, $newSerial);
 				if ($ret){
 					$this->setGuidanceMsg('データを更新しました');
@@ -415,7 +436,7 @@ class admin_event_mainEntryWidgetContainer extends admin_event_mainBaseWidgetCon
 			}
 			// エラーなしの場合は、データを削除
 			if ($this->getMsgCount() == 0){
-				$ret = $this->_db->delEntryItem(array($this->serialNo));
+				$ret = self::$_mainDb->delEntryItem(array($this->serialNo));
 				if ($ret){		// データ削除成功のとき
 					$this->setGuidanceMsg('データを削除しました');
 					
@@ -434,7 +455,7 @@ class admin_event_mainEntryWidgetContainer extends admin_event_mainBaseWidgetCon
 			}
 			// エラーなしの場合は、データを削除
 			if ($this->getMsgCount() == 0){
-				$ret = $this->_db->delEntryItemById($this->serialNo);
+				$ret = self::$_mainDb->delEntryItemById($this->serialNo);
 				if ($ret){		// データ削除成功のとき
 					$this->setGuidanceMsg('データを削除しました');
 					
@@ -459,7 +480,7 @@ class admin_event_mainEntryWidgetContainer extends admin_event_mainBaseWidgetCon
 		
 		// 設定データを再取得
 		if ($dataReload){		// データの再ロード
-			$ret = $this->_db->getEntryBySerial($this->serialNo, $row, $categoryRow);
+			$ret = self::$_mainDb->getEntryBySerial($this->serialNo, $row, $categoryRow);
 			if ($ret){
 				$this->entryId = $row['ee_id'];		// 記事ID
 				$name = $row['ee_name'];				// タイトル
@@ -483,12 +504,12 @@ class admin_event_mainEntryWidgetContainer extends admin_event_mainBaseWidgetCon
 				$receiveComment = $row['ee_receive_comment'];		// コメントを受け付けるかどうか
 		
 				// 記事カテゴリー取得
-				//$this->categoryArray = $this->getCategory($categoryRow);
+				$this->categoryArray = $this->getCategory($categoryRow);
 			}
 		}
 		// カテゴリーメニューを作成
-		//$this->_db->getAllCategory($this->langId, $this->categoryListData);
-		//$this->createCategoryMenu($this->categoryCount);
+		self::$_mainDb->getAllCategory($this->langId, $this->categoryListData);
+		$this->createCategoryMenu($this->categoryCount);
 		
 		// ### 入力値を再設定 ###
 		$this->tmpl->addVar('_widget', 'entry', $this->entryId);
@@ -545,7 +566,7 @@ class admin_event_mainEntryWidgetContainer extends admin_event_mainBaseWidgetCon
 			}
 			// 言語選択メニュー作成
 			//if (!empty($this->entryId)){	// コンテンツが選択されているとき
-			//	$this->_db->getAllLang(array($this, 'langLoop'));
+			//	self::$_mainDb->getAllLang(array($this, 'langLoop'));
 			//	$this->tmpl->setAttribute('select_lang', 'visibility', 'visible');
 			//}
 		}
@@ -571,13 +592,13 @@ class admin_event_mainEntryWidgetContainer extends admin_event_mainBaseWidgetCon
 
 		// カテゴリーを取得
 		$categoryArray = array();
-		$ret = $this->_db->getEntryBySerial($serial, $row, $categoryRow);
+		$ret = self::$_mainDb->getEntryBySerial($serial, $row, $categoryRow);
 		if ($ret){
 			for ($i = 0; $i < count($categoryRow); $i++){
 				if (function_exists('mb_strimwidth')){
-					$categoryArray[] = mb_strimwidth($categoryRow[$i]['bc_name'], 0, self::CATEGORY_NAME_SIZE, '…');
+					$categoryArray[] = mb_strimwidth($categoryRow[$i]['ec_name'], 0, self::CATEGORY_NAME_SIZE, '…');
 				} else {
-					$categoryArray[] = substr($categoryRow[$i]['bc_name'], 0, self::CATEGORY_NAME_SIZE) . '...';
+					$categoryArray[] = substr($categoryRow[$i]['ec_name'], 0, self::CATEGORY_NAME_SIZE) . '...';
 				}
 			}
 		}
@@ -659,19 +680,19 @@ class admin_event_mainEntryWidgetContainer extends admin_event_mainBaseWidgetCon
 	 * @param array  	$srcRows			取得行
 	 * @return array						取得した行
 	 */
-/*	function getCategory($srcRows)
+	function getCategory($srcRows)
 	{
 		$destArray = array();
 		$itemCount = 0;
 		for ($i = 0; $i < count($srcRows); $i++){
-			if (!empty($srcRows[$i]['bw_category_id'])){
-				$destArray[] = $srcRows[$i]['bw_category_id'];
+			if (!empty($srcRows[$i]['ew_category_id'])){
+				$destArray[] = $srcRows[$i]['ew_category_id'];
 				$itemCount++;
 				if ($itemCount >= $this->categoryCount) break;
 			}
 		}
 		return $destArray;
-	}*/
+	}
 	/**
 	 * 記事カテゴリーメニューを作成
 	 *
@@ -684,14 +705,14 @@ class admin_event_mainEntryWidgetContainer extends admin_event_mainBaseWidgetCon
 			// selectメニューの作成
 			$this->tmpl->clearTemplate('category_list');
 			for ($i = 0; $i < count($this->categoryListData); $i++){
-				$categoryId = $this->categoryListData[$i]['bc_id'];
+				$categoryId = $this->categoryListData[$i]['ec_id'];
 				$selected = '';
 				if ($j < count($this->categoryArray) && $this->categoryArray[$j] == $categoryId){
 					$selected = 'selected';
 				}
 				$menurow = array(
 					'value'		=> $categoryId,			// カテゴリーID
-					'name'		=> $this->categoryListData[$i]['bc_name'],			// カテゴリー名
+					'name'		=> $this->categoryListData[$i]['ec_name'],			// カテゴリー名
 					'selected'	=> $selected														// 選択中かどうか
 				);
 				$this->tmpl->addVars('category_list', $menurow);
@@ -712,7 +733,7 @@ class admin_event_mainEntryWidgetContainer extends admin_event_mainBaseWidgetCon
 	 */
 	function clearCacheBySerial($serial)
 	{
-		$ret = $this->_db->getEntryBySerial($serial, $row, $categoryRow);// 記事ID取得
+		$ret = self::$_mainDb->getEntryBySerial($serial, $row, $categoryRow);// 記事ID取得
 		if ($ret){
 			$entryId = $row['ee_id'];		// 記事ID
 			$urlParam = array();
